Learn R Programming

guescini (version 0.1.0)

IgG_inhibition: IgG inhibition

Description

This data set is for a set of quantitative real-time PCR runs that were performed in the presence of an optimal amplification reaction mix added with serial dilutions of IgG (0.0, 0.25, 0.50, 1.0, and 2.0 \(\mu g/ml\)) thus acting as the inhibitory agent. There are two replicates for each concentration of IgG. The concentration of the amplicon ND1/ND2 is 41,700,000 copies. Please read the Methods section of Guescini et al. (2008) for more details.

Arguments

Format

A tibble with 400 rows and 10 variables:

plate

Plate identifier.

well

Well identifier. Values are always NA (not available). This variable is kept nevertheless to be coherent with other data sets from other similar R data packages.

dye

The type of dye used. In this data set the values are always "SYBR", meaning SYBR Green I master mix (Roche).

target

Target identifier: the amplicon used, "MT_ND1".

sample_type

Sample type (all curves are standards, i.e. "std").

replicate

Replicate identifier: 1 thru 3.

IgG_conc

IgG concentration in \(\mu g/ml\).

copies

Standard copy number.

cycle

PCR cycle.

fluor

Raw fluorescence values.

Examples

Run this code
IgG_inhibition

Run the code above in your browser using DataLab