This data set is for a set of quantitative real-time PCR runs that were performed in the presence of an optimal amplification reaction mix added with serial dilutions of IgG (0.0, 0.25, 0.50, 1.0, and 2.0 \(\mu g/ml\)) thus acting as the inhibitory agent. There are two replicates for each concentration of IgG. The concentration of the amplicon ND1/ND2 is 41,700,000 copies. Please read the Methods section of Guescini et al. (2008) for more details.
A tibble with 400 rows and 10 variables:
platePlate identifier.
wellWell identifier. Values are always NA (not available). This
variable is kept nevertheless to be coherent with other data sets from other
similar R data packages.
dyeThe type of dye used. In this data set the values are always
"SYBR", meaning SYBR Green I master mix (Roche).
targetTarget identifier: the amplicon used, "MT_ND1".
sample_typeSample type (all curves are standards, i.e. "std").
replicateReplicate identifier: 1 thru 3.
IgG_concIgG concentration in \(\mu g/ml\).
copiesStandard copy number.
cyclePCR cycle.
fluorRaw fluorescence values.