This data set is for a set of quantitative real-time PCR runs that targets the amplification of a sequence of the MT-ND1 gene, for a seven-point, ten-fold a serial dilution starting at 3.14 x 10^7 copies of DNA molecules. In addition, a range of amplification mix quantities ranging from 60% to 100% are also performed. This results in 5 serial dilutions, one for each amplification mix quantity (0.6, 0.7, 0.8, 0.9 and 1.0). Please read the Methods section of Guescini et al. (2008) for more details.
Each data set comprises a seven-point, ten-fold dilution series, repeated in
12 independent runs targeting an amplicon for the MT-ND1 gene. A slight
amplification inhibition in the quantitative real-time PCR experiments was
obtained by using two systems: decreasing the amplification mix
(amp_mix_perc) used in the reaction and adding varying amounts of IgG, a
known PCR inhibitor. Please read the Methods section of Guescini et al.
(2008) for more details.
A tibble with 21,000 rows and 12 variables:
platePlate identifier.
wellWell identifier. Values are always NA (not available). This
variable is kept nevertheless to be coherent with other data sets from other
similar R data packages.
dyeThe type of dye used. In this data set the values are always
"SYBR", meaning SYBR Green I master mix (Roche).
targetTarget identifier: the amplicon used, "MT_ND1".
sample_typeSample type (all curves are standards, i.e. "std").
runThis variable discriminates amplification curves within the
group defined by amp_mix_perc and copies. Range: 1 thru 12.
replicateReplicate identifier: 1 thru 3.
amp_mix_percAmplification mix percentage.
copiesStandard copy number.
dilutionDilution factor. Higher number means greater dilution.
cyclePCR cycle.
fluorRaw fluorescence values.
A tibble with 21,000 rows and 11 variables:
platePlate identifier.
wellWell identifier. Values are always NA (not available). This
variable is kept nevertheless to be coherent with other data sets from other
similar R data packages.
dyeThe type of dye used. In this data set the values are always
"SYBR", meaning SYBR Green I master mix (Roche).
targetTarget identifier: the amplicon used, "MT_ND1".
sample_typeSample type (all curves are standards, i.e. "std").
replicateReplicate identifier: 1 thru 3.
amp_mix_percAmplification mix percentage.
copiesStandard copy number.
dilutionDilution factor. Higher number means greater dilution.
cyclePCR cycle.
fluorRaw fluorescence values.